#-- bibtexTidying 0.1.0 --

Author: Jian Ding and ShiBo Xu and Kun Chen
Email: xxxxx@yy.com
Mentor: X. Fu and TingYu Luo

##[Purpose]
This software is trying to help users to tidy up their bibtex files.

##[Prerequisite]
- Python3
- MySQL

##[Github]
https://gitee.com/chen-kun19/summer-program

##[Manual]
- **How to install it?**
  - use command following.
    - pip install bibtexTidying
- **How to use it?**
  - Type following code in your python files:
    - from bibtexTidying import bibcopy
- **Then you can use all the function in module bibcopy!**

##[Function]
     1.Formating your bibtex files.

##[Known Issues]:
      1.hahaha
  

##[Bug Report]:
	Any bug or documentation error you found , please submit an issue on github parge: https://gitee.com/chen-kun19/summer-program